@@ -1163,6 +1163,8 @@ meta_screen_ensure_tab_popup (MetaScreen *screen,
       entries[i].title = window->title;
       entries[i].icon = window->icon;
       entries[i].blank = FALSE;
+      entries[i].minimized = window->minimized;
+      entries[i].demands_attention = window->wm_state_demands_attention;
       
       if (!window->minimized || !meta_window_get_icon_geometry (window, &r))
         meta_window_get_outer_rect (window, &r);
@@ -1265,6 +1267,8 @@ meta_screen_ensure_workspace_popup (MetaScreen *screen)
           entries[i].icon = NULL;
           entries[i].blank = TRUE;
         }
+      entries[i].minimized = FALSE;
+      entries[i].demands_attention = FALSE;
 
       ++i;
     }
